@@ -242,11 +242,11 @@ setMethod("subtitles<-", "CrunchDeck", function(x, value) {
 #' @param deck A CrunchDeck
 #' @param file The file path to save the exported deck
 #' @param format Either `"xlsx"`, `"pptx"`, or `"json"`
-#'
+#' @param ... Further options to be passed on to the API
 #' @return  the filename (`file`, if specified, or the the autogenerated file
 #' name).
 #' @export
-exportDeck <- function(deck, file, format = c("xlsx", "pptx", "json")) {
+exportDeck <- function(deck, file, format = c("xlsx", "pptx", "json"), ...) {
     if (!inherits(deck, "CrunchDeck")) {
         halt("exportDeck is only available for CrunchDecks.")
     }
@@ -256,12 +256,16 @@ exportDeck <- function(deck, file, format = c("xlsx", "pptx", "json")) {
     if (missing(file)) {
         file <- paste0(name(deck), ".", format)
     }
+    body <- list(...)
+    if (length(body) == 0) {
+        body <- emptyObject()
+    }
     dl_link <- crPOST(
         url,
         body = toJSON(list(
             element = "shoji:entity",
-            body = emptyObject()
-            )),
+            body = body
+        )),
         config = add_headers(`Accept` = accept)
     )
     crDownload(dl_link, file)
