@@ -4,12 +4,12 @@ rethrow <- function(x) halt(errorMessage(x))
 
 errorMessage <- function(e) attr(e, "condition")$message
 
-warn_once <- function(..., call.=FALSE, option) {
+warn_once <- function(..., call. = FALSE, option) {
     # Warn the first time, then set an option so we know not to warn again in
     # the current session
     if (!isTRUE(getOption(option, FALSE))) {
-        warning(..., call.=call.)
-        opts <- structure(list(TRUE), .Names=option)
+        warning(..., call. = call.)
+        opts <- structure(list(TRUE), .Names = option)
         do.call(options, opts)
     }
 }
@@ -207,12 +207,11 @@ envOrOption <- function(opt, default = NULL) {
 #' @examples
 #' setCrunchAPI("local", 8080)
 #' setCrunchAPI("app")
-#'
 #' @keywords internal
 #' @export
 setCrunchAPI <- function(subdomain, port = NULL) {
     if (!is.null(port)) {
-        api <- paste0("http://", subdomain, ".crunch.io:", port, "/api/")
+        api <- paste0("http://", subdomain, ".crunch.io:", port, "/api/") # nolint
     } else {
         api <- paste0("https://", subdomain, ".crunch.io/api/")
     }
@@ -221,8 +220,8 @@ setCrunchAPI <- function(subdomain, port = NULL) {
 }
 
 
-# halt if variable is an array variable. If callingFunc is provided, provide the function that
-# the user used to get to this point.
+# halt if variable is an array variable. If callingFunc is provided, provide
+# the function that the user used to get to this point.
 haltIfArray <- function(variable, callingFunc) {
     # if the variable is not an array type, return quickly
     # TODO: should this also short-circuit if variable is not a variable?
@@ -253,7 +252,7 @@ haltIfArray <- function(variable, callingFunc) {
 is.TRUEorFALSE <- function(value) {
     return(is.logical(value) && length(value) == 1 && !is.na(value))
 }
-is.singleCharacter <- function(value){
+is.singleCharacter <- function(value) {
     return(is.character(value) && length(value) == 1)
 }
 
@@ -304,7 +303,7 @@ escapeRegex <- function(string) {
     return(gsub("(\\[|\\])", "\\\\\\1", out))
 }
 
-pluralize <- function (string, count) {
+pluralize <- function(string, count) {
     # Naive conditional pluralization
     ifelse(count == 1, string, paste0(string, "s"))
 }
