@@ -234,13 +234,32 @@ test_that("toVariable parses R Date class", {
     )
 })
 
-test_that("toVariable handles POSIX datetimes", {
-    skip("Investigate precision")
-    numtime <- 1454238117.123 ## Note that it's off by 1ms below...
+test_that("toVariable handles POSIX datetimes (and timezones)", {
+    numtime <- 1454238117.123
+
     expect_equivalent(
         toVariable(as.POSIXct(numtime, origin = "1970-01-01", tz = "UTC")),
         list(
-            values = "2016-01-31T03:01:57.122", type = "datetime",
+            values = "2016-01-31T11:01:57.123", type = "datetime",
+            resolution = "ms"
+        )
+    )
+
+    # We store times as UTC when they go between R and crunch's database, but we assume
+    # they actually refer to local times, so when we convert a variable of eg 5AM central
+    # time it gets stored as 5AM UTC
+    expect_equivalent(
+        toVariable(as.POSIXct(numtime, origin = "1970-01-01", tz = "America/Chicago")),
+        list(
+            values = "2016-01-31T05:01:57.123", type = "datetime",
+            resolution = "ms"
+        )
+    )
+
+    expect_equivalent(
+        toVariable(as.POSIXct(numtime, origin = "1970-01-01", tz = "America/New_York")),
+        list(
+            values = "2016-01-31T06:01:57.123", type = "datetime",
             resolution = "ms"
         )
     )
