@@ -157,6 +157,15 @@ with_mock_crunch({
             ),
             "Accept: application/vnd.openxmlformats-officedocument.presentationml.presentation"
         )
+        # ... arguments are passed
+        expect_header(
+            expect_POST(
+                exportDeck(main_deck, format = "json", slides = list(urls(slides(main_deck)[1]))),
+                "https://app.crunch.io/api/datasets/4/decks/8ad8/export/",
+                body = '{"element":"shoji:entity","body":{"slides":[',
+                '"https://app.crunch.io/api/datasets/4/decks/8ad8/slides/da161/"]}}'),
+            "Accept: application/json"
+        )
     })
 
     test_that("Deck export errors helpfully", {
@@ -247,6 +256,39 @@ with_mock_crunch({
         )
     })
 
+    test_that("New Slide - specify analyses", {
+        example_analyses <- list(list(
+            query = list(
+                dimensions = list(list(variable = self(ds$birthyr))),
+                measures = list(count = list(`function` = "cube_count", args = list()))
+            )
+        ))
+        example_analyses_json <- paste0(
+            '"analyses":[{"query":{"dimensions":[{"variable":"https://app.',
+            'crunch.io/api/datasets/4/variables/birthyr/"}],',
+            '"measures":{"count":{"function":"cube_count","args":[]}'
+        )
+
+        expect_POST(
+            newSlide(main_deck, NULL, title = "title", analyses = example_analyses),
+            "https://app.crunch.io/api/datasets/4/decks/8ad8/slides/",
+            '{"element":"shoji:entity",',
+            '"body":{"title":"title","subtitle":"",', example_analyses_json, "}}"
+        )
+
+        expect_error(
+            newSlide(main_deck, ~birthyr, analyses = example_analyses),
+            "Cannot specify both a `query` and `analyses` for `newSlide()`",
+             fixed = TRUE
+        )
+
+        expect_error(
+            newSlide(main_deck, NULL),
+            "Must specify either a `query` or `analyses` for `newSlide()`",
+            fixed = TRUE
+        )
+    })
+
     slide <- main_deck[[1]]
     test_that("Slide show method", {
         expect_prints(
@@ -638,6 +680,16 @@ with_mock_crunch({
         )
     })
 
+    test_that("Analysis list assignment", {
+        expect_PATCH(
+            analysis(slide) <- list(query = "query", display_settings = "settings"),
+            "https://app.crunch.io/api/datasets/4/decks/8ad8/slides/da161/analyses/bce96/",
+            '{"element":"shoji:entity","body":{"query":"query",',
+            '"display_settings":"settings"}}'
+        )
+
+    })
+
     test_that("analysis assignment errors", {
         expect_error(
             an_cat[[1]] <- list(~birthyr, ~gender),
@@ -739,6 +791,49 @@ with_mock_crunch({
             '"measures":{"count":{"function":"cube_count","args":[]}}}}}'
         )
     })
+
+    test_that("formulaToSlideQuery helper", {
+        # It's just a wrapper with different argument names for internal function
+        expect_equal(
+            formulaToSlideQuery(~birthyr, ds),
+            formulaToCubeQuery(~birthyr, ds)
+        )
+    })
+
+    test_that("slideQueryEnv helper", {
+        expect_equal(
+            slideQueryEnv(weight = ds$birthyr),
+            list(weight = list(self(ds$birthyr)))
+        )
+        expect_equal(
+            slideQueryEnv(weight = NULL),
+            list(weight = list())
+        )
+
+        filter <- filters(ds)[["Occasional Political Interest"]]
+        expect_equal(
+            slideQueryEnv(filter = filter),
+            list(filter = list(self(filter)))
+        )
+        expect_equal(
+            slideQueryEnv(filter = NULL),
+            list(filter = list())
+        )
+        expect_error(
+            slideQueryEnv(filter = ds$birthyr < 1980),
+            "ad-hoc filters not supported for slides"
+        )
+
+        expect_equal(
+            slideQueryEnv(weight = ds$birthyr, filter = filter),
+            list(weight = list(self(ds$birthyr)), filter = list(self(filter)))
+        )
+
+        expect_error(
+            slideQueryEnv(),
+            "Must specify at least one of `weight` or `filter`"
+        )
+    })
 })
 
 test_that("filter gets pass through method on non-crunch objects", {
