@@ -21,35 +21,21 @@ with_mock_crunch({
         expect_identical(entities(ordering(varcat)), entities(varorder))
     })
 
-    test_that("active/hidden getters", {
-        expect_is(hidden(varcat), "VariableFolder")
-        expect_length(hidden(varcat), 0)
-        expect_identical(
-            index(active(varcat)),
-            index(varcat)[urls(ordering(varcat))]
-        )
-        index(varcat)[[1]]$discarded <- TRUE
-        expect_is(active(varcat), "VariableCatalog")
-        # Specific behavior of "hidden" is tested in test-hide-variables.R
-        expect_identical(
-            urls(active(varcat)),
-            c(
-                "https://app.crunch.io/api/datasets/1/variables/gender/",
-                "https://app.crunch.io/api/datasets/1/variables/location/",
-                "https://app.crunch.io/api/datasets/1/variables/mymrset/",
-                "https://app.crunch.io/api/datasets/1/variables/textVar/",
-                "https://app.crunch.io/api/datasets/1/variables/starttime/",
-                "https://app.crunch.io/api/datasets/1/variables/catarray/"
-            )
-        )
-        expect_length(active(varcat), 6)
+    test_that("hidden getters", {
+        expect_is(hiddenFolder(varcat), "VariableFolder")
+        expect_length(hiddenFolder(varcat), 0)
     })
 
-    test_that("secure variables aren't considered active (#383)", {
-        index(varcat)[[1]]$secure <- TRUE
-
+    test_that("active variables don't include hidden (now a dataset property)", {
         expect_identical(
-            urls(active(varcat)),
+            index(variables(ds)),
+            index(varcat)[urls(ordering(varcat))]
+        )
+        ds@hiddenVariables <- ds@variables[1]
+        expect_is(variables(ds), "VariableCatalog")
+        # Specific behavior of "hidden" is tested in test-hide-variables.R
+        expect_identical(
+            urls(variables(ds)),
             c(
                 "https://app.crunch.io/api/datasets/1/variables/gender/",
                 "https://app.crunch.io/api/datasets/1/variables/location/",
@@ -59,7 +45,24 @@ with_mock_crunch({
                 "https://app.crunch.io/api/datasets/1/variables/catarray/"
             )
         )
-        expect_length(active(varcat), 6)
+        expect_length(variables(ds), 6)
+    })
+
+    test_that("private variables aren't considered active (#383)", {
+        ds@privateVariables <- ds@variables[1]
+
+        expect_identical(
+            urls(variables(ds)),
+            c(
+                "https://app.crunch.io/api/datasets/1/variables/gender/",
+                "https://app.crunch.io/api/datasets/1/variables/location/",
+                "https://app.crunch.io/api/datasets/1/variables/mymrset/",
+                "https://app.crunch.io/api/datasets/1/variables/textVar/",
+                "https://app.crunch.io/api/datasets/1/variables/starttime/",
+                "https://app.crunch.io/api/datasets/1/variables/catarray/"
+            )
+        )
+        expect_length(variables(ds), 6)
     })
 
     gender.url <- "https://app.crunch.io/api/datasets/1/variables/gender/"
